summaryrefslogtreecommitdiff
path: root/sd
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-05-25 11:20:10 +0200
committerNoel Grandin <noel@peralex.com>2015-05-26 08:30:18 +0200
commitbb7ce3137dbe12d67f393b95a437b18e3a63f8e7 (patch)
tree12d4b581ac21aaaa243d6d070b00a8695b624b92 /sd
parent3dc50a3b9afc6eec42fb9f657a4dfd236066892f (diff)
convert INVALIDATE constants to scoped enum
fixing a bug in Window::ImplMoveAllInvalidateRegions, and improving the IDL docs for XWindowPeer Change-Id: Idb774ac913945db2ac7c492c11cf86c370624c3d
Diffstat (limited to 'sd')
-rw-r--r--sd/source/ui/view/viewshe2.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sd/source/ui/view/viewshe2.cxx b/sd/source/ui/view/viewshe2.cxx
index 9969d0fe00c3..3abcdd89b0fc 100644
--- a/sd/source/ui/view/viewshe2.cxx
+++ b/sd/source/ui/view/viewshe2.cxx
@@ -345,9 +345,9 @@ void ViewShell::SetZoom(long nZoom)
// #i74769# Here is a 2nd way (besides Window::Scroll) to set the visible prt
// of the window. It needs - like Scroll(SCROLL_CHILDREN) does - also to move
// the child windows. I am trying INVALIDATE_CHILDREN here which makes things better,
// but does not solve the problem completely. Neet to ask PL.
- mpContentWindow->Invalidate(INVALIDATE_CHILDREN);
+ mpContentWindow->Invalidate(InvalidateFlags::Children);
}
Size aVisSizePixel = GetActiveWindow()->GetOutputSizePixel();
@@ -393,7 +393,7 @@ void ViewShell::SetZoomRect(const Rectangle& rZoomRect)
// When tiled rendering, UpdateMapOrigin() doesn't touch the map mode.
if (!GetDoc()->isTiledRendering())
// #i74769# see above
- mpContentWindow->Invalidate(INVALIDATE_CHILDREN);
+ mpContentWindow->Invalidate(InvalidateFlags::Children);
}
Size aVisSizePixel = GetActiveWindow()->GetOutputSizePixel();
@@ -345,9 +345,9 @@ void ViewShell::SetZoom(long nZoom)
// #i74769# Here is a 2nd way (besides Window::Scroll) to set the visible prt
// of the window. It needs - like Scroll(SCROLL_CHILDREN) does - also to move
- // the child windows. I am trying INVALIDATE_CHILDREN here which makes things better,
+ // the child windows. I am trying InvalidateFlags::Children here which makes things better,
// but does not solve the problem completely. Neet to ask PL.